@@ -309,7 +309,7 @@ if __name__ == "__main__":
     try:
         while True:
             print(color('[DeviceAcThor] test active. Press CTRL+C to stop', fore='blue', style='bright'))
-            device.showinfo()
+            print(device.getinfo())
             device.showcommunicationerrors()
             device.showcommunicationerrorsrate()
             device._supervise()
@@ -340,7 +340,7 @@ if __name__ == "__main__":
     try:
         while True:
             print(color('[DeviceAcThor] DCS communication active. Press CTRL+C to stop', fore='blue', style='bright'))
-            # device.showInfo()
+            # print(device.getinfo())
             device.showcommunicationerrors()
             device.showcommunicationerrorsrate()
             # device2.showcommunicationerrors()
