@@ -24,8 +24,6 @@ class DeviceDcElwa(ModbusRtuDevice):
     _serial = None
     _irerror = False
     _errorcode = 0
-    _oldacdaywh = None
-    _oldacdaywhlog = None
 
     def __init__(self, serial, unitId):
         super().__init__(unitId)
@@ -90,17 +88,8 @@ class DeviceDcElwa(ModbusRtuDevice):
         else:
             acHeating = False
 
-        if self._oldacdaywh != None:
-            if self._oldacdaywh != acdaywh:
-                acchanged = True
-            else:
-                acchanged = False
-        else:
-            self._oldacdaywh = acdaywh
-            acchanged = False
-
         if acRelayState != None:
-            if acHeating == True and acRelayState == 1 and acchanged == True:
+            if acHeating == True and acRelayState == 1:
                 boostpower = 750
             else:
                 boostpower = 0
@@ -108,7 +97,7 @@ class DeviceDcElwa(ModbusRtuDevice):
             boostpower = None
 
         if(boostpower != None):
-            power = (int(dcPower) + int(boostpower))
+            power = dcPower + boostpower
             meter = -boostpower
         else:
             power = dcPower
@@ -170,20 +159,8 @@ class DeviceDcElwa(ModbusRtuDevice):
         acRelayState = self.getlogvalue("ac_relay_state")
         acdaywh = self.getlogvalue("ac_day_wh")
 
-        if self._oldacdaywhlog != None:
-            if self._oldacdaywhlog != acdaywh:
-                acchanged = True
-            else:
-                acchanged = False
-        else:
-            self._oldacdaywhlog = acdaywh
-            acchanged = False
-
         if acRelayState != None:
-            if acchanged == False:
-                boostpower = 0
-            else:
-                boostpower = int(round(acRelayState*self._deviceBoostpower))
+            boostpower = int(round(acRelayState*750))
         else:
             boostpower = None
         
