@@ -83,7 +83,7 @@ class ElwaSc20(SerialDevice):
         self._channels["is_master_device"] = ChannelConfig([26], "NUMBER", 0, registertype="serial")
         self._channels["serial"] = ChannelConfig([27], None, 0, registertype="serial", mode="rw")
         self._channels["pot_position"] = ChannelConfig([28], "NUMBER", 0, registertype="serial")
-        self._channels["useacboost"] = ChannelConfig([30], "NUMBER", 0, registertype="serial", mode="rw")
+        self._channels["useacboost"] = ChannelConfig([30], "NUMBER", 0, registertype="serial", mode="rw", datasettype="avg")
 
         self._setup["fwversion"] = SetupMapping(defaultvalue=self._firmwareversion) #required to find write configuration in cloud
         self._setup["device"] = SetupMapping(defaultvalue=self._devicesubtype)
@@ -196,22 +196,23 @@ class ElwaSc20(SerialDevice):
             "ac_day_wh": self.getchannelvalue("ac_day_wh", True),
             # "ac_boost_mode": self.getchannelvalue("ac_boost_mode", True),
             "m1sum": dcPower,
-            "m0sum": meter,
+            # "m0sum": meter,
             "buserrorrate":  errorrate
             # "errorcode_elwa": errorcode
         }
         if self._devicesubtype == "SC20":
-            data["power_sc20"] = power
+            # data["power_sc20"] = power
             data["device"] =  "SC20"
         else:
-            data["power_elwa"] = power
+            # data["power_elwa"] = power
             data["device"] =  "ELWA-USB"
         return data
 
     def getlogdata(self, time = None):
         acRelayState = self.getlogvalue("ac_relay_state")
+        useacboost = self.getlogvalue("useacboost")
 
-        if acRelayState != None:
+        if acRelayState != None and useacboost != None and useacboost >= 0.5:
             boostpower = int(round(acRelayState * self._deviceBoostpower))
         else:
             boostpower = None
@@ -235,10 +236,10 @@ class ElwaSc20(SerialDevice):
 
         logData = {
             "time": time,
-            "i_power": power,
-            "i_boostpower": boostpower,
+            # "i_power": power,
+            # "i_boostpower": boostpower,
             "i_m1sum": pvprod,
-            "i_metercons": metercons,
+            # "i_metercons": metercons,
             "i_temp1": self.getlogvalue("water_temp", "int", 10)
             # "s_json" : json.dumps(sLog)
         }
@@ -246,19 +247,22 @@ class ElwaSc20(SerialDevice):
         return logData
 
     def _checksumcheck(self, response_string, receivedchecksum):
-        return
-        # checksum = 0
-        # lasttab = response_string.rfind('\\t')
-        # payloadstring = response_string[2:lasttab]
-        # # payloadstring += "\\r\\n'"
-        # for c in payloadstring:
-        #     value = ord(c)
-        #     print(value)
-        #     checksum += value
-        #     checksum = checksum % 255
+        checksum = 0
+        lasttab = response_string.rfind('\\t')
+        payloadstring = response_string[2:lasttab+2]
+        for c in payloadstring:
+            if c == '\\':
+                value = 9
+                checksum += value
+            elif c == 't':
+                pass
+            else:
+                value = ord(c)
+                checksum += value
+        checksum = checksum % 256
 
-        # if receivedchecksum != checksum:
-        #     raise Exception("Checksum missmatch.")
+        if receivedchecksum != checksum:
+            raise Exception("Checksum missmatch.")
 
     def _supervise(self):
         super()._supervise()
